import wx
import ExtendedCalendarCtrl as EC
#import datetime


class Frame(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, "EccDemo CalendarCtrl", size=(320, 550))
        self.panel = wx.Panel(self)
        self.panel.SetBackgroundColour("#fbb60a")

        format = (lambda dt: (f'{dt.Format("%A %d %B %Y")}'))
        self.calendar = EC.CalendarCtrl(self.panel, -1, date=0, formatter=format,\
                                   calendar_style=wx.adv.CAL_SHOW_WEEK_NUMBERS|wx.adv.CAL_SEQUENTIAL_MONTH_SELECTION,\
                                   calendar_locale=wx.LANGUAGE_SPANISH)

        #font = wx.SystemSettings.GetFont(wx.SYS_SYSTEM_FONT)
        #font.SetFractionalPointSize(16)
        #self.calendar.SetCalendarFont(font)
        self.Notes = {
                                     (0, 1, 1) : "New Year's Day",
                                     (0, 2, -98) : "Last week day of February",
                                     (0, 0, -53) : "Pay Day! - 3rd Friday of the month",
                                     (2023, 8, 15) : "Random holiday in 2023",
                                     (2023, 10, 1) : "1st Oct 2023",
                                     (0, 12, 25) : "Christmas Day",
                                     (0, 12, 26) : "Boxing Day"
                                      }
        self.calendar.SetCalendarNotes(self.Notes)

        self.Holidays = {
                                     (0, 1) : [1,],                                 # January 1st every year
                                     (2023, 8) : [15],                              # Random holiday in 2023
                                     (0, 12) : [25,26]                              # 25th & 26th December every year
                                    }

        self.calendar.SetCalendarHolidays(self.Holidays)

        # Only effective if the 'holidays' pckage is available
        self.Hols = self.calendar.AddPublicHolidays(country="US", subdiv="TX", language="")   # USA, Texas

        txt1 = wx.StaticText(self.panel, -1, 'Event Details')
        self.details = wx.TextCtrl(self.panel, -1, value='', size=(300, 300), style=wx.TE_MULTILINE|wx.TE_READONLY|wx.HSCROLL)
        self.addnote = wx.CheckBox(self.panel, -1, label='Add a Note')
        self.addhol = wx.CheckBox(self.panel, -1, label='Add a Holiday')
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.calendar, 0, wx.EXPAND, 0)
        sizerh = wx.BoxSizer(wx.HORIZONTAL)
        sizerh.Add(self.addnote, 0, wx.ALL, 5)
        sizerh.Add(self.addhol, 0, wx.ALL, 5)
        sizer.Add(sizerh)
        sizer.Add(txt1, 0, wx.EXPAND|wx.ALL, 5)
        sizer.Add(self.details, 0, wx.EXPAND|wx.ALL, 5)
        self.panel.SetSizer(sizer)
        self.Centre()
        self.calendar.Bind(EC.EVT_DATE_CHANGED, self.OnEvent)

        # Bind to internal wxCalendar events for demonstration purposes
        self.calendar.Bind(wx.adv.EVT_CALENDAR_MONTH, self.OnCalMthEvt)
        self.calendar.Bind(wx.adv.EVT_CALENDAR_YEAR, self.OnCalYrEvt)
        self.addnote.Bind(wx.EVT_CHECKBOX, self.AddNote)
        self.addhol.Bind(wx.EVT_CHECKBOX, self.AddHol)

        self.Show()

# Testing
#        print(self.calendar.GetValue())
#        print(self.calendar.GetDate())
#        print(self.calendar.GetDateTimeValue())
#        print(self.calendar.GetTimeStamp())
#        print(self.calendar.GetLocale())
#        print(self.calendar.GetNotes())
#        print(self.calendar.GetHolidays())
#        print(self.calendar.GetMarkDates())
#        print(self.calendar.GetRestrictedDates())
#        d = datetime.datetime.now()
#        d = d + datetime.timedelta(days=3)
#        self.calendar.TriggerDateEvent(d)

    def OnEvent(self, event):
        msg = "Extended Calendar Event\n"
        obj = event.GetEventObject()
        msg += "\nFormatted: "+str(event.GetValue())

        x = event.GetDate() # wx.DateTime object
        msg += "\nwxDate: "+str(x)
        msg += "\nDay: "+str(x.GetDayOfYear())+" Week "+str(x.GetWeekOfYear())+" Name "+str(x.GetWeekDayName(x.GetWeekDay()))
        msg += "\nDatetime: "+str(event.GetDateTime()) # datetime.datetime object
        msg += "\nTimestamp: "+str(event.GetTimeStamp())
        msg += "\nNotes: "+str(event.GetNote())
        msg += "\nMarked: "+str(event.IsMarked())
        msg += "\nCalendar Holiday: "+str(event.IsHoliday())
        msg += "\nPublic Holiday: "+str(event.IsPublicHoliday())
        msg += "\nLocale: "+str(obj.GetLocale())
        self.details.SetValue(msg)

    def OnCalMthEvt(self, event):
        # Internal wx.CalendarCtrl events
        obj = event.GetEventObject()
        msg = "wxCalendar Month changed Event\n"+str(event.Date)

    def OnCalYrEvt(self, event):
        # Internal wx.CalendarCtrl Year change event
        # Demonstrate altering details
        msg = "wxCalendar Year changed Event\n"+str(event.Date)+"\nNotes have been changed - Pay Day moved"
        if self.Hols:
            msg += "\nHolidays are now for Japan in English"
        self.details.SetValue(msg)
        if self.Notes.get((0, 0, -53), ''):
            self.Notes.pop((0, 0, -53))     # Remove the 3rd Friday pay day entry and replace it
            self.Notes[(0, 0, -52)] = "Pay Day! - 2nd Friday of the month"
        elif self.Notes.get((0, 0, -52), ''):
            self.Notes.pop((0, 0, -52))     # Remove the 2nd Friday pay day entry and replace it
            self.Notes[(0, 0, -53)] = "Pay Day! - 3rd Friday of the month"
        self.calendar.SetCalendarNotes(self.Notes)
        self.calendar.AddPublicHolidays(country="JP", subdiv="", language="en_US", replace=True)    # Japan

    def AddNote(self, event):
        wx.CallLater(1000, self.ClearNote, False)
        AddCalendarNote(self)

    def ClearNote(self, value=False):
        self.addnote.SetValue(value)

    def AddHol(self, event):
        wx.CallLater(1000, self.ClearHol, False)
        AddCalendarHoliday(self)

    def ClearHol(self, value=False):
        self.addhol.SetValue(value)

class AddCalendarNote(wx.Dialog):
    def __init__(self, parent, title="Add a Note", date=0):
        wx.Dialog.__init__(self, parent, wx.ID_ANY, size=(-1, -1))
        self.parent = parent
        cal_date = parent.calendar.GetValue()
        self.SetBackgroundColour(parent.panel.GetBackgroundColour())
        self.SetTitle("Note for "+cal_date)
        self.note = wx.TextCtrl(self, -1, size=(300, 50), style=wx.TE_MULTILINE)
        self.add_button = wx.Button(self, label="Add", style=wx.BU_EXACTFIT)
        self.quit_button = wx.Button(self, label="Quit", style=wx.BU_EXACTFIT)
        sz = wx.BoxSizer(wx.VERTICAL)
        txsz = wx.StaticBoxSizer(wx.HORIZONTAL, self, "Note")
        txsz.Add(self.note, 0, wx.ALL, 10)
        sz.Add(txsz, 0, wx.ALIGN_RIGHT| wx.ALL, 5)
        btsz = wx.BoxSizer(wx.HORIZONTAL)
        btsz.Add(self.add_button, 0, wx.ALL, 5)
        btsz.Add(self.quit_button, 0, wx.ALL, 5)
        sz.Add(btsz, 0, wx.ALL, 10)
        self.SetSizerAndFit(sz)
        self.add_button.Bind(wx.EVT_BUTTON, self.OnAdd)
        self.quit_button.Bind(wx.EVT_BUTTON, self.OnQuit)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)
        self.Show()

    def OnAdd(self, event):
        new_note = self.note.GetValue()
        nd = self.parent.calendar.GetDate()
        old_note = self.parent.Notes.get((nd.year, nd.month + 1, nd.day), '')
        if old_note:
            new_note = old_note + "\n+ " + new_note
        self.parent.Notes[(nd.year, nd.month + 1, nd.day)] = new_note
        self.parent.calendar.SetCalendarNotes(self.parent.Notes)
        self.OnQuit(None)

    def OnQuit(self, event):
        result = None
        self.Destroy()
        return result


class AddCalendarHoliday(wx.Dialog):
    def __init__(self, parent, title="Add a Holiday", date=0):
        wx.Dialog.__init__(self, parent, wx.ID_ANY, size=(-1, -1))
        self.parent = parent
        cal_date = parent.calendar.GetValue()
        self.SetBackgroundColour(parent.panel.GetBackgroundColour())
        self.SetTitle("Holiday for "+cal_date)
        self.note = wx.TextCtrl(self, -1, size=(300, 50), style=wx.TE_MULTILINE)
        self.add_button = wx.Button(self, label="Add", style=wx.BU_EXACTFIT)
        self.quit_button = wx.Button(self, label="Quit", style=wx.BU_EXACTFIT)
        sz = wx.BoxSizer(wx.VERTICAL)
        txsz = wx.StaticBoxSizer(wx.HORIZONTAL, self, "Holiday Note")
        txsz.Add(self.note, 0, wx.ALL, 10)
        sz.Add(txsz, 0, wx.ALIGN_RIGHT| wx.ALL, 5)
        btsz = wx.BoxSizer(wx.HORIZONTAL)
        btsz.Add(self.add_button, 0, wx.ALL, 5)
        btsz.Add(self.quit_button, 0, wx.ALL, 5)
        sz.Add(btsz, 0, wx.ALL, 10)
        self.SetSizerAndFit(sz)
        self.add_button.Bind(wx.EVT_BUTTON, self.OnAdd)
        self.quit_button.Bind(wx.EVT_BUTTON, self.OnQuit)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)
        self.Show()

    def OnAdd(self, event):
        new_note = self.note.GetValue()
        nd = self.parent.calendar.GetDate()
        hols = self.parent.Holidays.get((nd.year, nd.month + 1), [])
        if hols and nd.day in hols: # Don't duplicate the entry
            pass
        else:
            hols.append(nd.day)
        self.parent.Holidays[(nd.year, nd.month + 1)] = hols
        self.parent.calendar.SetCalendarHolidays(self.parent.Holidays)
        # Add note
        old_note = self.parent.Notes.get((nd.year, nd.month + 1, nd.day), '')
        if old_note:
            new_note = old_note + "\n+ " + new_note
        self.parent.Notes[(nd.year, nd.month + 1, nd.day)] = new_note
        self.parent.calendar.SetCalendarNotes(self.parent.Notes)
        self.OnQuit(None)

    def OnQuit(self, event):
        result = None
        self.Destroy()
        return result


app = wx.App()
frame = Frame(None)
app.MainLoop()
