import wx
import ExtendedCalendarCtrl as EC

class Frame(wx.Frame):
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, "EccDemo CalendarCtrl", size=(320, 550))
        panel = wx.Panel(self)
        panel.SetBackgroundColour("#fbb60a")

        format = (lambda dt: (f'{dt.Format("%A %d %B %Y")}'))
        self.calendar = EC.CalendarCtrl(panel, -1, date=0, formatter=format,\
                                   calendar_style=wx.adv.CAL_SEQUENTIAL_MONTH_SELECTION|wx.adv.CAL_SHOW_WEEK_NUMBERS,\
                                   calendar_locale=wx.LANGUAGE_SPANISH)

        #font = wx.SystemSettings.GetFont(wx.SYS_SYSTEM_FONT)
        #font.SetFractionalPointSize(16)
        #self.calendar.SetCalendarFont(font)
        self.calendar.SetCalendarNotes({
                                     (0, 1, 1) : "New Year's Day",
                                     (0, 2, -98) : "Last week day of February",
                                     (0, 0, -53) : "Pay Day! - 3rd Friday of the month",
                                     (0, 12, 25) : "Christmas Day",
                                     (0, 12, 26) : "Boxing Day"
                                      })
        self.calendar.SetCalendarHolidays({
                                     (0, 1) : [1,],                                 # January 1st every year
                                     (2023, 8) : [15],                              # Random holiday in 2023
                                     (0, 12) : [25,26]                              # 25th & 26th December every year
                                    })

        self.Hols = self.calendar.AddPublicHolidays(country="US", subdiv="TX", language="")   # USA, Texas

        txt1 = wx.StaticText(panel, -1, 'Event Details')
        self.details = wx.TextCtrl(panel, -1, value='', size=(300, 300), style=wx.TE_MULTILINE|wx.TE_READONLY|wx.HSCROLL)
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.calendar, 0, wx.EXPAND, 0)
        sizer.Add(txt1, 0, wx.EXPAND|wx.ALL, 5)
        sizer.Add(self.details, 0, wx.EXPAND|wx.ALL, 5)
        panel.SetSizer(sizer)
        self.Centre()
        self.calendar.Bind(EC.EVT_DATE_CHANGED, self.OnEvent)

        # Bind to internal wxCalendar events for demonstration purposes
        self.calendar.Bind(wx.adv.EVT_CALENDAR_MONTH, self.OnCalMthEvt)
        self.calendar.Bind(wx.adv.EVT_CALENDAR_YEAR, self.OnCalYrEvt)

        self.Show()

    def OnEvent(self, event):
        msg = "Extended Calendar Event\n"
        obj = event.GetEventObject()
        msg += "\nFormatted: "+str(event.GetValue())

        x = event.GetDate() # wx.DateTime object
        msg += "\nwxDate: "+str(x)
        msg += "\nDay: "+str(x.GetDayOfYear())+" Week "+str(x.GetWeekOfYear())+" Name "+str(x.GetWeekDayName(x.GetWeekDay()))
        msg += "\nDatetime: "+str(event.GetDateTime()) # datetime.datetime object
        msg += "\nTimestamp: "+str(event.GetTimeStamp())
        msg += "\nNotes: "+str(event.GetNote())
        msg += "\nMarked: "+str(event.IsMarked())
        msg += "\nCalendar Holiday: "+str(event.IsHoliday())
        msg += "\nPublic Holiday: "+str(event.IsPublicHoliday())
        msg += "\nLocale: "+str(obj.GetLocale())
        self.details.SetValue(msg)

    def OnCalMthEvt(self, event):
        # Internal wx.CalendarCtrl events
        obj = event.GetEventObject()
        msg = "wxCalendar Month changed Event\n"+str(event.Date)
        self.details.SetValue(msg)

    def OnCalYrEvt(self, event):
        # Internal wx.CalendarCtrl Year change event
        # Demonstrate altering details
        msg = "wxCalendar Year changed Event\n"+str(event.Date)+"\nNotes have been changed - Pay Day moved"
        if self.Hols:
            msg += "\nHolidays are now for Japan in English"
        self.details.SetValue(msg)
        self.calendar.SetCalendarNotes({
                                     (0, 1, 1) : "New Year's Day",
                                     (0, 2, -98) : "Last week day of February",
                                     (0, 0, -52) : "Pay Day! - 2nd Friday of the month",
                                     (0, 12, 25) : "Christmas Day",
                                     (0, 12, 26) : "Boxing Day"
                                      })
        self.calendar.AddPublicHolidays(country="JP", subdiv="", language="en_US", replace=True)    # Japan


app = wx.App()
frame = Frame(None)
app.MainLoop()
